package com.ruoyi.post.frequency.post.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.post.controller.req.PostPageReq;
import com.ruoyi.post.controller.req.PostReleaseReq;
import com.ruoyi.post.frequency.post.entity.Post;
import com.ruoyi.post.frequency.post.model.result.PostCount;
import com.ruoyi.response.ResponseData;
import com.ruoyi.vo.UserVo;

import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 帖子Service接口
 *
 * @author liwenlong
 * @date 2023-10-09
 */
public interface PostService extends IService<Post>
{
    /**
     * 查询帖子
     *
     * @param id 帖子主键
     * @return 帖子
     */
    public Post selectPostById(Long id);

    /**
     * 查询帖子列表
     *
     * @param post 帖子
     * @return 帖子集合
     */
    public List<Post> selectPostList(Post post);

    PostCount statistics(Post post);

    /**
     * 新增帖子
     *
     * @param post 帖子
     * @return 结果
     */
    public int insertPost(Post post);

    /**
     * 修改帖子
     *
     * @param post 帖子
     * @return 结果
     */
    public int updatePost(Post post);

    int updatePostLikeNum(Post post, Integer num);

    /**
     * 批量删除帖子
     *
     * @param ids 需要删除的帖子主键集合
     * @return 结果
     */
    public int deletePostByIds(Long[] ids);

    /**
     * 删除帖子信息
     *
     * @param id 帖子主键
     * @return 结果
     */
    public int deletePostById(Long id);

    /**
     * 帖子发布
     * @param req
     * @param userVo
     * @return
     */
    ResponseData postRelease(PostReleaseReq req, UserVo userVo);


    /**
     * 帖子列表
     * @param req
     * @param userVo 登入用户
     * @return
     */
    ResponseData postPage(PostPageReq req, UserVo userVo);


    /**
     * 帖子详情
     * @param postId 帖子id
     * @param userVo 登入用户
     * @return
     */
    ResponseData postDetail(Long postId,Integer isAddBrowseNum, UserVo userVo);

    /**
     * 查询帖子
     * @param postIds
     * @return
     */
    Map<Long, Post> selectPostMap(Set<Long> postIds);

    /**
     * 帖子修改
     * @param req
     * @param userVo
     * @return
     */
    ResponseData postEdit(PostReleaseReq req, UserVo userVo);

    /**
     * 帖子删除
     * @param id
     * @param userVo
     * @return
     */
    ResponseData postDelete(Long id, UserVo userVo);

    /**
     * 帖子置顶/取消置顶
     * @param id
     * @return
     */
    AjaxResult topping(Long id);

}
